/*


██╗   ██╗ ██████╗    ██████╗  ██████╗ ██████╗ ██████╗ 
██║   ██║██╔════╝    ╚════██╗██╔═████╗╚════██╗╚════██╗
██║   ██║██║          █████╔╝██║██╔██║ █████╔╝ █████╔╝
╚██╗ ██╔╝██║         ██╔═══╝ ████╔╝██║██╔═══╝ ██╔═══╝ 
 ╚████╔╝ ╚██████╗    ███████╗╚██████╔╝███████╗███████╗
  ╚═══╝   ╚═════╝    ╚══════╝ ╚═════╝ ╚══════╝╚══════╝
                                                      
@As initial crate push test to https://crates.io registry

*/


pub mod push_to_crates {

    pub fn print_dummy_data(data:&str){

        println!("Hello {}",data)

    }

    pub mod simple_math{

        pub fn add_33(operand:i32)->i32{
            
            operand+33
            
        }

        fn priv_func_minus20(operand:i32)->u32{

            (operand-20) as u32

        }


        pub static MAX_BYTES:u16=1799;

    }

}